'use strict';

var assert = require('assert');
var scalar = require('../index').scalar;

var alpha = {
  zero: function zero() {
    return '*';
  },
  linearInterpolate: function linearInterpolate(a, b, t) {
    return scalar.linearInterpolate(a.charCodeAt(0), b.charCodeAt(0), t);
  },
  smoothInterpolate: function smoothInterpolate(a, b, t) {
    return scalar.smoothInterpolate(a.charCodeAt(0), b.charCodeAt(0), t);
  },
  keyframeInterpolate: function keyframeInterpolate(keyframes, t) {
    var timing = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'linear';
    var lib = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : alpha;

    var result = scalar.keyframeInterpolate(keyframes, t, timing, lib);
    return String.fromCharCode(Math.round(result));
  }
};

describe('custom interplation lib', function () {

  it('interpolates from a-z', function () {

    var keyframes = [{ stop: 0, value: 'a' }, { stop: 25, value: 'z' }];

    var result = alpha.keyframeInterpolate(keyframes, 0);
    assert.equal(result, 'a');

    result = alpha.keyframeInterpolate(keyframes, 6);
    assert.equal(result, 'g');

    result = alpha.keyframeInterpolate(keyframes, 19);
    assert.equal(result, 't');

    result = alpha.keyframeInterpolate(keyframes, 25);
    assert.equal(result, 'z');

    result = alpha.keyframeInterpolate(keyframes, 26);
    assert.equal(result, 'z');
  });
});
//# sourceMappingURL=custom_spec.js.map